package com.ruoyi.system.service.impl;

import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.system.domain.blackManage.BlackManage;
import com.ruoyi.system.mapper.BlackManageMapper;
import com.ruoyi.system.service.IBlackManageService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 黑名单管理Service业务层处理
 * 
 * @author boman
 * @date 2025-02-17
 */
@Service
public class BlackManageServiceImpl implements IBlackManageService 
{
    @Autowired
    private BlackManageMapper blackManageMapper;

    /**
     * 查询黑名单管理
     * 
     * @param blackManageId 黑名单管理主键
     * @return 黑名单管理
     */
    @Override
    public BlackManage selectBlackManageByBlackManageId(Long blackManageId)
    {
        return blackManageMapper.selectBlackManageByBlackManageId(blackManageId);
    }

    /**
     * 查询黑名单管理列表
     * 
     * @param blackManage 黑名单管理
     * @return 黑名单管理
     */
    @Override
    public List<BlackManage> selectBlackManageList(BlackManage blackManage)
    {
        return blackManageMapper.selectBlackManageList(blackManage);
    }

    /**
     * 新增黑名单管理
     * 
     * @param blackManage 黑名单管理
     * @return 结果
     */
    @Override
    public int insertBlackManage(BlackManage blackManage)
    {
        blackManage.setCreateTime(DateUtils.getNowDate());
        return blackManageMapper.insertBlackManage(blackManage);
    }

    /**
     * 修改黑名单管理
     * 
     * @param blackManage 黑名单管理
     * @return 结果
     */
    @Override
    public int updateBlackManage(BlackManage blackManage)
    {
        blackManage.setUpdateTime(DateUtils.getNowDate());
        return blackManageMapper.updateBlackManage(blackManage);
    }

    /**
     * 批量删除黑名单管理
     * 
     * @param blackManageIds 需要删除的黑名单管理主键
     * @return 结果
     */
    @Override
    public int deleteBlackManageByBlackManageIds(Long[] blackManageIds)
    {
        return blackManageMapper.deleteBlackManageByBlackManageIds(blackManageIds);
    }

    /**
     * 删除黑名单管理信息
     * 
     * @param blackManageId 黑名单管理主键
     * @return 结果
     */
    @Override
    public int deleteBlackManageByBlackManageId(Long blackManageId)
    {
        return blackManageMapper.deleteBlackManageByBlackManageId(blackManageId);
    }
}
