package com.ruoyi.system.service.impl;

import com.ruoyi.common.core.redis.RedisCache;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.system.domain.complaintSuggestion.ComplaintSuggestion;
import com.ruoyi.system.domain.suggestionFj.SuggestionFj;
import com.ruoyi.system.mapper.ComplaintSuggestionMapper;
import com.ruoyi.system.mapper.SuggestionFjMapper;
import com.ruoyi.system.service.IComplaintSuggestionService;
import org.apache.commons.lang3.ObjectUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

import static com.ruoyi.common.constant.Constants.*;

/**
 * 投诉建议Service业务层处理
 * 
 * @author boman
 * @date 2025-02-14
 */
@Service
public class ComplaintSuggestionServiceImpl implements IComplaintSuggestionService 
{
    @Autowired
    private ComplaintSuggestionMapper complaintSuggestionMapper;

    @Autowired
    private SuggestionFjMapper suggestionFjMapper;

    @Autowired
    private RedisCache redisCache;

    /**
     * 查询投诉建议
     * 
     * @param suggestionId 投诉建议主键
     * @return 投诉建议
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public ComplaintSuggestion selectComplaintSuggestionBySuggestionId(Long suggestionId)
    {
        ComplaintSuggestion complaintSuggestion = complaintSuggestionMapper.selectComplaintSuggestionBySuggestionId(suggestionId);
        SuggestionFj suggestionFj = new SuggestionFj();
        suggestionFj.setSuggestionId(suggestionId);
        List<SuggestionFj> suggestionFjs = suggestionFjMapper.selectSuggestionFjList(suggestionFj);
        if (suggestionFjs != null && suggestionFjs.size() > 0){
            complaintSuggestion.setSuggestionFjList(suggestionFjs);
        }
        //判断是否已读如果是未读设置成已读
        String isRead = complaintSuggestion.getIsRead();
        Long userId = complaintSuggestion.getUserId();
        if (N.equals(isRead) && userId.equals(SecurityUtils.getUserId())){
            complaintSuggestion.setIsRead(Y);
            complaintSuggestionMapper.updateComplaintSuggestion(complaintSuggestion);
            //app首页统计减少一个数
            String userSuggestionKey = COMPLAINT_SUGGESTION_NO + userId;
            //往redis中新增 个人 投诉建议未回复的数量 app统计使用 回复了这个用户的投诉，这个用户能看到
            Object userNum = redisCache.getCacheObject(userSuggestionKey);
            if (ObjectUtils.isNotEmpty(userNum)) {
                redisCache.setCacheObject(userSuggestionKey, Math.max((int) userNum - 1, 0));
            }else {
                redisCache.setCacheObject(userSuggestionKey,0);
            }
        }
        return complaintSuggestion;
    }

    /**
     * 查询投诉建议列表
     * 
     * @param complaintSuggestion 投诉建议
     * @return 投诉建议
     */
    @Override
    public List<ComplaintSuggestion> selectComplaintSuggestionList(ComplaintSuggestion complaintSuggestion)
    {
        return complaintSuggestionMapper.selectComplaintSuggestionList(complaintSuggestion);
    }

    /**
     * 新增投诉建议
     * 
     * @param complaintSuggestion 投诉建议
     * @return 结果
     */
    @Override
    public int insertComplaintSuggestion(ComplaintSuggestion complaintSuggestion)
    {
        Long userId = SecurityUtils.getUserId();
        complaintSuggestion.setCreateTime(DateUtils.getNowDate());
        complaintSuggestion.setUserId(userId);
        int result = complaintSuggestionMapper.insertComplaintSuggestion(complaintSuggestion);
        if (result > 0){
            //往redis中新增 总数 投诉建议未回复的数量 app统计使用
            Object allNum = redisCache.getCacheObject(COMPLAINT_SUGGESTION_NO_ALL);
            if (ObjectUtils.isNotEmpty(allNum)) {
                redisCache.setCacheObject(COMPLAINT_SUGGESTION_NO_ALL, Math.max((int) allNum + 1, 0));
            }else {
                redisCache.setCacheObject(COMPLAINT_SUGGESTION_NO_ALL,1);
            }
        }
        return result;
    }

    /**
     * 修改投诉建议
     * 
     * @param complaintSuggestion 投诉建议
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public int updateComplaintSuggestion(ComplaintSuggestion complaintSuggestion)
    {
        Long userId = complaintSuggestion.getUserId();
        String status = complaintSuggestion.getStatus();
        if (TWO.equals(status)){
            //判断是否有附件
            List<SuggestionFj> suggestionFjList = complaintSuggestion.getSuggestionFjList();
            if (suggestionFjList != null && suggestionFjList.size() > 0){
                suggestionFjMapper.batchSuggestionFj(suggestionFjList);
            }
            String userSuggestionKey = COMPLAINT_SUGGESTION_NO + userId;
            //往redis中新增 个人 投诉建议未回复的数量 app统计使用 回复了这个用户的投诉，这个用户能看到
            Object userNum = redisCache.getCacheObject(userSuggestionKey);
            if (ObjectUtils.isNotEmpty(userNum)) {
                redisCache.setCacheObject(userSuggestionKey, Math.max((int) userNum + 1, 0));
            }else {
                redisCache.setCacheObject(userSuggestionKey,1);
            }
            //往redis中新增 总数 投诉建议未回复的数量 app统计使用
            Object allNum = redisCache.getCacheObject(COMPLAINT_SUGGESTION_NO_ALL);
            if (ObjectUtils.isNotEmpty(allNum)) {
                redisCache.setCacheObject(COMPLAINT_SUGGESTION_NO_ALL, Math.max((int) allNum - 1, 0));
            }else {
                redisCache.setCacheObject(COMPLAINT_SUGGESTION_NO_ALL,0);
            }
        }

        complaintSuggestion.setUpdateTime(DateUtils.getNowDate());
        return complaintSuggestionMapper.updateComplaintSuggestion(complaintSuggestion);
    }

    /**
     * 批量删除投诉建议
     * 
     * @param suggestionIds 需要删除的投诉建议主键
     * @return 结果
     */
    @Override
    public int deleteComplaintSuggestionBySuggestionIds(Long[] suggestionIds)
    {
        return complaintSuggestionMapper.deleteComplaintSuggestionBySuggestionIds(suggestionIds);
    }

    /**
     * 删除投诉建议信息
     * 
     * @param suggestionId 投诉建议主键
     * @return 结果
     */
    @Override
    public int deleteComplaintSuggestionBySuggestionId(Long suggestionId)
    {
        return complaintSuggestionMapper.deleteComplaintSuggestionBySuggestionId(suggestionId);
    }
}
