package com.ruoyi.system.service.impl;

import com.ruoyi.common.core.redis.RedisCache;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.system.domain.visitor.VisitorManage;
import com.ruoyi.system.mapper.VisitorManageMapper;
import com.ruoyi.system.service.IVisitorManageService;
import org.apache.commons.lang3.ObjectUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

import static com.ruoyi.common.constant.Constants.NOW_MONTH_VISITOR_CAR;
import static com.ruoyi.common.constant.Constants.Y;

/**
 * 来访管理Service业务层处理
 *
 * @author boman
 * @date 2025-02-14
 */
@Service
public class VisitorManageServiceImpl implements IVisitorManageService {
    @Autowired
    private VisitorManageMapper visitorManageMapper;

    @Autowired
    private RedisCache redisCache;

    /**
     * 查询来访管理
     *
     * @param visitorManageId 来访管理主键
     * @return 来访管理
     */
    @Override
    public VisitorManage selectVisitorManageByVisitorManageId(Long visitorManageId) {
        return visitorManageMapper.selectVisitorManageByVisitorManageId(visitorManageId);
    }

    /**
     * 查询来访管理列表
     *
     * @param visitorManage 来访管理
     * @return 来访管理
     */
    @Override
    public List<VisitorManage> selectVisitorManageList(VisitorManage visitorManage) {
        return visitorManageMapper.selectVisitorManageList(visitorManage);
    }

    /**
     * 新增来访管理
     *
     * @param visitorManage 来访管理
     * @return 结果
     */
    @Override
    public int insertVisitorManage(VisitorManage visitorManage) {
        //todo 车牌需要进入道闸系统临时车
        visitorManage.setCreateTime(DateUtils.getNowDate());
        visitorManage.setVisitorTime(DateUtils.getNowDate());
        //统计中外来车辆
        if (Y.equals(visitorManage.getIsCar())) {
            int currentMonth = 1;
            Object nowMonthRedis = redisCache.getCacheObject(NOW_MONTH_VISITOR_CAR + DateUtils.getMonth());
            if (ObjectUtils.isNotEmpty(nowMonthRedis)) {
                currentMonth = (int) nowMonthRedis + currentMonth;
            }
            redisCache.setCacheObject(NOW_MONTH_VISITOR_CAR + DateUtils.getMonth(), currentMonth);
        }
        return visitorManageMapper.insertVisitorManage(visitorManage);
    }

    /**
     * 修改来访管理
     *
     * @param visitorManage 来访管理
     * @return 结果
     */
    @Override
    public int updateVisitorManage(VisitorManage visitorManage) {
        if (Y.equals(visitorManage.getIsCar())) {
            VisitorManage visitorManageOld = visitorManageMapper.selectVisitorManageByVisitorManageId(visitorManage.getVisitorManageId());
            if (!Y.equals(visitorManageOld.getIsCar())) {
                int currentMonth = 1;
                Object nowMonthRedis = redisCache.getCacheObject(NOW_MONTH_VISITOR_CAR + DateUtils.getMonth());
                if (ObjectUtils.isNotEmpty(nowMonthRedis)) {
                    currentMonth = (int) nowMonthRedis + currentMonth;
                }
                redisCache.setCacheObject(NOW_MONTH_VISITOR_CAR + DateUtils.getMonth(), currentMonth);
            }
        }
        visitorManage.setUpdateTime(DateUtils.getNowDate());
        return visitorManageMapper.updateVisitorManage(visitorManage);
    }

    /**
     * 批量删除来访管理
     *
     * @param visitorManageIds 需要删除的来访管理主键
     * @return 结果
     */
    @Override
    public int deleteVisitorManageByVisitorManageIds(Long[] visitorManageIds) {
        return visitorManageMapper.deleteVisitorManageByVisitorManageIds(visitorManageIds);
    }

    /**
     * 删除来访管理信息
     *
     * @param visitorManageId 来访管理主键
     * @return 结果
     */
    @Override
    public int deleteVisitorManageByVisitorManageId(Long visitorManageId) {
        return visitorManageMapper.deleteVisitorManageByVisitorManageId(visitorManageId);
    }
}
